@@ -26,6 +26,8 @@ import {
   VariableOption,
   defaultDataQueryKind,
   AdHocFilterWithLabels,
+  SwitchVariableKind,
+  defaultIntervalVariableSpec,
 } from '@grafana/schema/dist/esm/schema/dashboard/v2';
 import { getDefaultDatasource } from 'app/features/dashboard/api/ResponseTransformers';
 
@@ -33,7 +35,7 @@ import { getIntervalsQueryFromNewIntervalModel } from '../utils/utils';
 
 import { DSReferencesMapping } from './DashboardSceneSerializer';
 import { getDataSourceForQuery } from './layoutSerializers/utils';
-import { getDataQueryKind, getDataQuerySpec, getElementDatasource } from './transformSceneToSaveModelSchemaV2';
+import { getDataQueryKind, getElementDatasource } from './transformSceneToSaveModelSchemaV2';
 import {
   transformVariableRefreshToEnum,
   transformVariableHideToEnum,
@@ -60,7 +62,6 @@ export function sceneVariablesSetToVariables(set: SceneVariables, keepQueryOptio
       skipUrlSync: Boolean(variable.state.skipUrlSync),
       hide: variable.state.hide || OldVariableHide.dontHide,
       type: variable.state.type,
-      showInControlsMenu: variable.state.showInControlsMenu,
     };
 
     if (sceneUtils.isQueryVariable(variable)) {
@@ -211,6 +212,24 @@ export function sceneVariablesSetToVariables(set: SceneVariables, keepQueryOptio
         filters: [...validateFiltersOrigin(variable.state.originFilters), ...variable.state.filters],
         defaultKeys: variable.state.defaultKeys,
       });
+    } else if (sceneUtils.isSwitchVariable(variable)) {
+      variables.push({
+        ...commonProperties,
+        current: {
+          value: variable.state.value,
+          text: variable.state.value,
+        },
+        options: [
+          {
+            value: variable.state.enabledValue,
+            text: variable.state.enabledValue,
+          },
+          {
+            value: variable.state.disabledValue,
+            text: variable.state.disabledValue,
+          },
+        ],
+      });
     } else if (variable.state.type === 'system') {
       // Not persisted
     } else {
@@ -265,6 +284,7 @@ export function sceneVariablesSetToSchemaV2Variables(
   | ConstantVariableKind
   | GroupByVariableKind
   | AdhocVariableKind
+  | SwitchVariableKind
 > {
   let variables: Array<
     | QueryVariableKind
@@ -275,6 +295,7 @@ export function sceneVariablesSetToSchemaV2Variables(
     | ConstantVariableKind
     | GroupByVariableKind
     | AdhocVariableKind
+    | SwitchVariableKind
   > = [];
 
   for (const variable of set.state.variables) {
@@ -284,7 +305,6 @@ export function sceneVariablesSetToSchemaV2Variables(
       description: variable.state.description ?? undefined,
       skipUrlSync: Boolean(variable.state.skipUrlSync),
       hide: transformVariableHideToEnum(variable.state.hide) || defaultVariableHide(),
-      showInControlsMenu: variable.state.showInControlsMenu,
     };
 
     // current: VariableOption;
@@ -296,6 +316,8 @@ export function sceneVariablesSetToSchemaV2Variables(
     };
 
     let options: VariableOption[] = [];
+
+    // Query variable
     if (sceneUtils.isQueryVariable(variable)) {
       // Not sure if we actually have to still support this option given
       // that it's not exposed in the UI
@@ -310,27 +332,30 @@ export function sceneVariablesSetToSchemaV2Variables(
         dataQuery = {
           kind: 'DataQuery',
           version: defaultDataQueryKind().version,
-          group: datasource?.type ?? getDataQueryKind(query),
+          group: datasource?.type || getDataQueryKind(query),
           ...(datasource?.uid && {
             datasource: {
               name: datasource.uid,
             },
           }),
-          spec: getDataQuerySpec(query),
+          spec: query,
         };
       } else {
+        // Only include LEGACY_STRING_VALUE_KEY if query is a non-empty string
+        const spec: Record<string, string> = {};
+        if (query) {
+          spec[LEGACY_STRING_VALUE_KEY] = query;
+        }
         dataQuery = {
           kind: 'DataQuery',
           version: defaultDataQueryKind().version,
-          group: datasource?.type ?? getDataQueryKind(query),
+          group: datasource?.type || getDataQueryKind(query),
           ...(datasource?.uid && {
             datasource: {
               name: datasource.uid,
             },
           }),
-          spec: {
-            [LEGACY_STRING_VALUE_KEY]: query,
-          },
+          spec,
         };
       }
       const queryVariable: QueryVariableKind = {
@@ -343,7 +368,7 @@ export function sceneVariablesSetToSchemaV2Variables(
           definition: variable.state.definition,
           sort: transformSortVariableToEnum(variable.state.sort),
           refresh: transformVariableRefreshToEnum(variable.state.refresh),
-          regex: variable.state.regex,
+          regex: variable.state.regex ?? '',
           allValue: variable.state.allValue,
           includeAll: variable.state.includeAll || false,
           multi: variable.state.isMulti || false,
@@ -357,6 +382,8 @@ export function sceneVariablesSetToSchemaV2Variables(
         },
       };
       variables.push(queryVariable);
+
+      // Custom variable
     } else if (sceneUtils.isCustomVariable(variable)) {
       options = variableValueOptionsToVariableOptions(variable.state);
       const customVariable: CustomVariableKind = {
@@ -373,6 +400,8 @@ export function sceneVariablesSetToSchemaV2Variables(
         },
       };
       variables.push(customVariable);
+
+      // Datasource variable
     } else if (sceneUtils.isDataSourceVariable(variable)) {
       const datasourceVariable: DatasourceVariableKind = {
         kind: 'DatasourceVariable',
@@ -380,9 +409,9 @@ export function sceneVariablesSetToSchemaV2Variables(
           ...commonProperties,
           current: currentVariableOption,
           options: [],
-          regex: variable.state.regex,
+          regex: variable.state.regex ?? '',
           refresh: 'onDashboardLoad',
-          pluginId: variable.state.pluginId,
+          pluginId: variable.state.pluginId ?? getDefaultDatasource().type,
           multi: variable.state.isMulti || false,
           includeAll: variable.state.includeAll || false,
           allowCustomValue: variable.state.allowCustomValue ?? true,
@@ -394,21 +423,24 @@ export function sceneVariablesSetToSchemaV2Variables(
       }
 
       variables.push(datasourceVariable);
+
+      // Constant variable
     } else if (sceneUtils.isConstantVariable(variable)) {
+      const value = variable.state.value ? String(variable.state.value) : '';
       const constantVariable: ConstantVariableKind = {
         kind: 'ConstantVariable',
         spec: {
           ...commonProperties,
           current: {
-            ...currentVariableOption,
-            // Constant variable doesn't use text state
-            text: String(variable.state.value),
+            text: value,
+            value: value,
           },
-          // @ts-expect-error
-          query: variable.state.value,
+          query: value,
         },
       };
       variables.push(constantVariable);
+
+      // Interval variable
     } else if (sceneUtils.isIntervalVariable(variable)) {
       const intervals = getIntervalsQueryFromNewIntervalModel(variable.state.intervals);
       const intervalVariable: IntervalVariableKind = {
@@ -421,22 +453,24 @@ export function sceneVariablesSetToSchemaV2Variables(
             text: variable.state.value,
           },
           query: intervals,
-          refresh: 'onTimeRangeChanged',
+          refresh: defaultIntervalVariableSpec().refresh,
           options: variable.state.intervals.map((interval) => ({
             value: interval,
             text: interval,
             selected: interval === variable.state.value,
           })),
-          auto: variable.state.autoEnabled,
-          auto_min: variable.state.autoMinInterval,
-          auto_count: variable.state.autoStepCount,
+          auto: variable.state.autoEnabled ?? defaultIntervalVariableSpec().auto,
+          auto_min: variable.state.autoMinInterval ?? defaultIntervalVariableSpec().auto_min,
+          auto_count: variable.state.autoStepCount ?? defaultIntervalVariableSpec().auto_count,
         },
       };
       variables.push(intervalVariable);
+
+      // Textbox variable
     } else if (sceneUtils.isTextBoxVariable(variable)) {
       const current = {
-        text: variable.state.value,
-        value: variable.state.value,
+        text: variable.state.value ?? '',
+        value: variable.state.value ?? '',
       };
 
       const textBoxVariable: TextVariableKind = {
@@ -444,11 +478,13 @@ export function sceneVariablesSetToSchemaV2Variables(
         spec: {
           ...commonProperties,
           current,
-          query: variable.state.value,
+          query: variable.state.value ?? '',
         },
       };
 
       variables.push(textBoxVariable);
+
+      // Groupby variable
     } else if (sceneUtils.isGroupByVariable(variable) && config.featureToggles.groupByVariable) {
       options = variableValueOptionsToVariableOptions(variable.state);
 
@@ -485,6 +521,8 @@ export function sceneVariablesSetToSchemaV2Variables(
         },
       };
       variables.push(groupVariable);
+
+      // Adhoc variable
     } else if (sceneUtils.isAdHocVariable(variable)) {
       const ds = getDataSourceForQuery(
         variable.state.datasource,
@@ -510,6 +548,19 @@ export function sceneVariablesSetToSchemaV2Variables(
         },
       };
       variables.push(adhocVariable);
+
+      // Switch variable
+    } else if (sceneUtils.isSwitchVariable(variable)) {
+      const switchVariable: SwitchVariableKind = {
+        kind: 'SwitchVariable',
+        spec: {
+          ...commonProperties,
+          current: variable.state.value,
+          enabledValue: variable.state.enabledValue,
+          disabledValue: variable.state.disabledValue,
+        },
+      };
+      variables.push(switchVariable);
     } else if (variable.state.type === 'system') {
       // Do nothing
     } else {
